@@ -92,9 +92,9 @@ hotkey_t *find_hotkey(xcb_keysym_t keysym, xcb_button_t button, uint16_t modfiel
 		if (num_active > 0) {
 			chained = true;
 			put_status(BEGIN_CHAIN_PREFIX, "Begin chain");
-			grab_chord(escape_chord);
+			grab_chord(abort_chord);
 		}
-	} else if (num_active == 0 || match_chord(escape_chord, event_type, keysym, button, modfield)) {
+	} else if (num_active == 0 || match_chord(abort_chord, event_type, keysym, button, modfield)) {
 		abort_chain();
 		return find_hotkey(keysym, button, modfield, event_type, replay_event);
 	}
@@ -120,7 +120,7 @@ chord_t *make_chord(xcb_keysym_t keysym, xcb_button_t button, uint16_t modfield,
 		chord_t *prev = NULL;
 		chord_t *orig = NULL;
 		xcb_keycode_t *keycodes = keycodes_from_keysym(keysym);
-		if (keycodes != NULL)
+		if (keycodes != NULL) {
 			for (xcb_keycode_t *kc = keycodes; *kc != XCB_NO_SYMBOL; kc++) {
 				xcb_keysym_t natural_keysym = xcb_key_symbols_get_keysym(symbols, *kc, 0);
 				for (unsigned char col = 0; col < KEYSYMS_PER_KEYCODE; col++) {
@@ -154,6 +154,9 @@ chord_t *make_chord(xcb_keysym_t keysym, xcb_button_t button, uint16_t modfield,
 					}
 				}
 			}
+		} else {
+			warn("No keycodes found for keysym %u.\n", keysym);
+		}
 		free(keycodes);
 		chord = orig;
 	} else {
@@ -243,6 +246,7 @@ void destroy_chain(chain_t *chain)
 		destroy_chord(c);
 		c = n;
 	}
+	free(chain);
 }
 
 void destroy_chord(chord_t *chord)
